; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = "some_name"
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /F, a    ;hold fwd while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;               command = ~30
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their engine.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted


;-| Super Motions |--------------------------------------------------------
[Command]
name = "TiltAWhirl"
command = ~$D, F, a+b

[Command]
name = "TiltAWhirl"
command = ~$D, F, b+c

[Command]
name = "TiltAWhirl"
command = ~$D, F, a+c

[Command]
name = "Super_Fireball"
command = ~$D, F, x+y

[Command]
name = "Super_Fireball"
command = ~$D, F, y+z

[Command]
name = "Super_Fireball"
command = ~$D, F, x+z

[Command]
name = "Super_Somersault"
command = ~30$B, F, x+y

[Command]
name = "Superkick"
command = ~$D, B, a+b
time = 30

[Command]
name = "Superkick"
command = ~$D, B, b+c

[Command]
name = "Superkick"
command = ~$D, B, a+c

[Command]
name = "Super_Somersault"
command = ~30$B, F, y+z

[Command]
name = "Super_Somersault"
command = ~30$B, F, x+z

[Command]
name = "Party_Crasher"
command = ~30$B, F, a+b

[Command]
name = "Party_Crasher"
command = ~30$B, F, b+c

[Command]
name = "Party_Crasher"
command = ~30$B, F, a+c

;-| Special Motions |------------------------------------------------------
[Command]
name = "QCF_a"
command = ~$D, F, a

[Command]
name = "QCF_b"
command = ~$D, F, b

[Command]
name = "QCF_c"
command = ~$D, F, c

[Command]
name = "QCF_x"
command = ~$D, F, x

[Command]
name = "QCF_y"
command = ~$D, F, y

[Command]
name = "QCF_z"
command = ~$D, F, z
                   
[Command]
name = "QCB_a"
command = ~$D, F, a

[Command]
name = "QCB_b"
command = ~$D, F, b

[Command]
name = "DP_x"
command = ~F, D, $F, x
time = 26

[Command]
name = "DP_y"
command = ~F, D, $F, y
time = 26

[Command]
name = "DP_z"
command = ~F, D, $F, z
time = 26

[Command]
name = "BF_x"
command = ~30$B, F, x

[Command]
name = "BF_y"
command = ~30$B, F, y

[Command]
name = "BF_z"
command = ~30$B, F, z

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF";Required (do not remove)
command = F, F
time = 17

[Command]
name = "BB";Required (do not remove)
command = B, B
time = 17

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = a+b

name = "recovery"
command = x+y

[Command]
name = "ab"
command = a+b

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "fwd_a"
command = /F,a
time = 1

[Command]
name = "fwd_b"
command = /F,b
time = 1

[Command]
name = "fwd_c"
command = /F,c
time = 1

[Command]
name = "fwd_x"
command = /F,x
time = 1

[Command]
name = "fwd_y"
command = /F,y
time = 1

[Command]
name = "fwd_z"
command = /F,z
time = 1
[Command]
name = "downfwd_a"
command = /DF,a
time = 1

[Command]
name = "downfwd_b"
command = /DF,b
time = 1

[Command]
name = "back_a"
command = /B,a
time = 1

[Command]
name = "back_b"
command = /B,b
time = 1

[Command]
name = "back_c"
command = /B,c
time = 1

[Command]
name = "back_x"
command = /B,x
time = 1

[Command]
name = "back_y"
command = /B,y
time = 1

[Command]
name = "back_z"
command = /B,z
time = 1

[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

[Command]
name = "down_c"
command = /$D,c
time = 1

[Command]
name = "down_x"
command = /$D,x
time = 1

[Command]
name = "fwd_ab"
command = /F, a+b
time = 1

[Command]
name = "back_ab"
command = /B, a+b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup";Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1]                  ;Don't change this
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = "command_name"
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
;---------------------------------------------------------------------------
;Party Crasher
[State -1]
type = ChangeState
value = 4000
triggerall = command = "Party_Crasher"
triggerall = power >= 3000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = statetype != A
trigger2 = hitdefattr = SC, NA, SA
trigger2 = movecontact = 1

;---------------------------------------------------------------------------
;TiltAWhirl Toss
[State -1]
type = ChangeState
value = 3820
triggerall = statetype = S
triggerall = ctrl = 1
triggerall = stateno != 100    ;Not running
triggerall = p2bodydist X < 8
triggerall = p2movetype != H
;triggerall = p2statetype = SC
triggerall = p2statetype !=A
triggerall = power >= 2000
trigger1 = command = "TiltAWhirl"

;---------------------------------------------------------------------------
;Superkick
[State -1]
type = NULL
value = 3060
triggerall = command = "Superkick"
triggerall = power >= 1000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = statetype != A
trigger2 = hitdefattr = SC, NA, SA
trigger2 = movecontact = 1

;---------------------------------------------------------------------------
;Super Fireball
[State -1]
type = ChangeState
value = 3010
triggerall = command = "Super_Fireball"
triggerall = power >= 1000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = statetype != A
trigger2 = hitdefattr = SC, NA, SA
trigger2 = movecontact = 1

;---------------------------------------------------------------------------
;Super Fireball
[State -1]
type = ChangeState
value = 3030
triggerall = command = "Super_Somersault"
triggerall = power >= 1000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = statetype != A
trigger2 = hitdefattr = SC, NA, SA
trigger2 = movecontact = 1

;===========================================================================

;Rising Thunder_X
[State -1]
type = ChangeState
value = 1050
triggerall = command = "DP_x"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 400
trigger4 = movecontact = 1
trigger5 = stateno = 410
trigger5 = movecontact = 1
trigger6 = stateno = 240
trigger6 = movecontact = 1
trigger7 = stateno = 440
trigger7 = movecontact = 1

;Rising Thunder_y
[State -1]
type = ChangeState
value = 1055
triggerall = command = "DP_y"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 400
trigger4 = movecontact = 1
trigger5 = stateno = 410
trigger5 = movecontact = 1
trigger6 = stateno = 240
trigger6 = movecontact = 1
trigger7 = stateno = 440
trigger7 = movecontact = 1

;---------------------------------------------------------------------------
;Rising Thunder_Z
[State -1]
type = ChangeState
value = 1060
triggerall = command = "DP_z"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 400
trigger4 = movecontact = 1
trigger5 = stateno = 410
trigger5 = movecontact = 1
trigger6 = stateno = 240
trigger6 = movecontact = 1
trigger7 = stateno = 440
trigger7 = movecontact = 1


;---------------------------------------------------------------------------
;somersault_X
[State -1]
type = ChangeState
value = 1030
triggerall = command = "BF_x"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 400
trigger4 = movecontact = 1
trigger5 = stateno = 410
trigger5 = movecontact = 1
trigger6 = stateno = 240
trigger6 = movecontact = 1
trigger7 = stateno = 440
trigger7 = movecontact = 1

;---------------------------------------------------------------------------
;somersault_Y
[State -1]
type = ChangeState
value = 1035
triggerall = command = "BF_y"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 400
trigger4 = movecontact = 1
trigger5 = stateno = 410
trigger5 = movecontact = 1
trigger6 = stateno = 240
trigger6 = movecontact = 1
trigger7 = stateno = 440
trigger7 = movecontact = 1

;---------------------------------------------------------------------------
;somersault_Z
[State -1]
type = ChangeState
value = 1040
triggerall = command = "BF_z"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 400
trigger4 = movecontact = 1
trigger5 = stateno = 410
trigger5 = movecontact = 1
trigger6 = stateno = 240
trigger6 = movecontact = 1
trigger7 = stateno = 440
trigger7 = movecontact = 1

;---------------------------------------------------------------------------
;Fireball_X
[State -1]
type = ChangeState
value = 1010
triggerall = command = "QCF_x"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 400
trigger4 = movecontact = 1
trigger5 = stateno = 410
trigger5 = movecontact = 1
trigger6 = stateno = 240
trigger6 = movecontact = 1
trigger7 = stateno = 440
trigger7 = movecontact = 1

;---------------------------------------------------------------------------
;Fireball_y
[State -1]
type = ChangeState
value = 1015
triggerall = command = "QCF_y"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 400
trigger4 = movecontact = 1
trigger5 = stateno = 410
trigger5 = movecontact = 1
trigger6 = stateno = 240
trigger6 = movecontact = 1
trigger7 = stateno = 440
trigger7 = movecontact = 1


;---------------------------------------------------------------------------
;Fireball_Z
[State -1]
type = ChangeState
value = 1020
triggerall = command = "QCF_z"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1
trigger3 = stateno = 210
trigger3 = movecontact = 1
trigger4 = stateno = 400
trigger4 = movecontact = 1
trigger5 = stateno = 410
trigger5 = movecontact = 1
trigger6 = stateno = 240
trigger6 = movecontact = 1
trigger7 = stateno = 440
trigger7 = movecontact = 1

;===========================================================================
;---------------------------------------------------------------------------
;RunFwd
[State -1]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;RunBack
[State -1]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Stand_Throw_YZ
[State -1]
type = ChangeState
value = 800
triggerall = statetype = S
triggerall = ctrl = 1
triggerall = stateno != 100    ;Not running
triggerall = p2bodydist X < 8
triggerall = p2movetype != H
;triggerall = p2statetype = SC
triggerall = p2statetype !=A
trigger1 = command = "fwd_y"
trigger2 = command = "fwd_z"
trigger3 = command = "back_y"
trigger4 = command = "back_z"

;---------------------------------------------------------------------------
;Counter_Throw_YZ
[State -1]
type = ChangeState
value = 800
triggerall = statetype = S
triggerall = stateno = [150,152]
triggerall = stateno != 151
;triggerall = p2statetype = SC
trigger1 = command = "fwd_y"
trigger2 = command = "fwd_z"
trigger3 = command = "back_y"
trigger4 = command = "back_z"

;---------------------------------------------------------------------------
;Stand_Throw_BC
[State -1]
type = ChangeState
value = 820
triggerall = statetype = S
triggerall = ctrl = 1
triggerall = stateno != 100    ;Not running
triggerall = p2bodydist X < 8
triggerall = p2movetype != H
;triggerall = p2statetype = SC
triggerall = p2statetype !=A
trigger1 = command = "fwd_b"
trigger2 = command = "fwd_c"
trigger3 = command = "back_b"
trigger4 = command = "back_c"

;---------------------------------------------------------------------------
;Counter_Throw_BC
[State -1]
type = ChangeState
value = 820
triggerall = statetype = S
triggerall = stateno = [150,152]
triggerall = stateno != 151
;triggerall = p2statetype = SC
trigger1 = command = "fwd_b"
trigger2 = command = "fwd_c"
trigger3 = command = "back_b"
trigger4 = command = "back_c"


;---------------------------------------------------------------------------
;Air_Throw1
[State -1]
type = ChangeState
value = 950
triggerall = statetype = A
triggerall = ctrl = 1
trigger1 = command = "fwd_ab"
trigger2 = command = "back_ab"
;---------------------------
;Air_Throw1 (second set of commands)
[State -1]
type = ChangeState
value = 950
triggerall = statetype = A
triggerall = ctrl = 1
triggerall = p2bodydist X < 9
triggerall = p2bodydist Y > -22
triggerall = p2bodydist Y < 22
triggerall = p2statetype = A
triggerall = p2movetype != H
trigger1 = command = "fwd_b"
trigger2 = command = "back_b"


;===========================================================================
;---------------------------------------------------------------------------
;Stand_Z
[State -1]
type = ChangeState
value = 240
triggerall = command = "z"
triggerall = command != "holddown"
;triggerall = P2Bodydist X <= 20
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1

;---------------------------------------------------------------------------
;Stand_C
[State -1]
type = ChangeState
value = 260
triggerall = command = "c"
triggerall = command != "holddown"
;triggerall = P2Bodydist X <= 20
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1

;---------------------------------------------------------------------------
;Stand_Close_A
[State -1]
type = ChangeState
value = 250
triggerall = command = "a"
triggerall = command != "holddown"
triggerall = P2Bodydist X <= 20
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = time > 7

;---------------------------------------------------------------------------
;Stand_X
[State -1]
type = ChangeState
value = 200
triggerall = command = "x"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = time > 7

;---------------------------------------------------------------------------
;Stand_Y
[State -1]
type = ChangeState
value = 210
triggerall = command = "y"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1

;---------------------------------------------------------------------------
;Stand_A
[State -1]
type = ChangeState
value = 220
triggerall = command = "a"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = time > 7

;---------------------------------------------------------------------------
;Stand_B
[State -1]
type = ChangeState
value = 230
triggerall = command = "b"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 200
trigger2 = movecontact = 1

;---------------------------------------------------------------------------
;Crouch_x
[State -1]
type = ChangeState
value = 440
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Crouch_y
[State -1]
type = ChangeState
value = 400
triggerall = command = "y"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Crouch_z
[State -1]
type = ChangeState
value = 410
triggerall = command = "z"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 400 ;crouch_a
trigger2 = movecontact = 1
trigger3 = stateno = 500 ;crouch_fwd_a
trigger3 = movecontact = 1

;---------------------------------------------------------------------------
;Crouch_a
[State -1]
type = ChangeState
value = 450
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
;---------------------------------------------------------------------------
;Crouch_b
[State -1]
type = ChangeState
value = 420
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Crouch_c
[State -1]
type = ChangeState
value = 430
triggerall = command = "c"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl = 1
trigger2 = stateno = 400 ;crouch_a
trigger2 = movecontact = 1
trigger3 = stateno = 500 ;crouch_fwd_a
trigger3 = movecontact = 1

;---------------------------------------------------------------------------
;Jump_Down_X Forward (Splash)
[State -1]
type = ChangeState
value = 640
triggerall = Vel X != 0
trigger1 = command = "down_x"
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Jump_X
[State -1]
type = ChangeState
value = 600
trigger1 = command = "x"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = command = "x";-------
trigger2 = stateno = 600 ;jump_a
trigger2 = statetime >= 6

;---------------------------------------------------------------------------
;Jump_Y
[State -1]
type = ChangeState
value = 605
trigger1 = command = "y"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = command = "y";-------
trigger2 = stateno = 600 ;jump_a
trigger2 = movecontact = 1

;---------------------------------------------------------------------------
;Jump_Z
[State -1]
type = ChangeState
value = 610
trigger1 = command = "z"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = command = "y";-------
trigger2 = stateno = 600 ;jump_a
trigger2 = movecontact = 1

;---------------------------------------------------------------------------
;Jump_A
[State -1]
type = ChangeState
value = 620
triggerall = Vel X = 0
trigger1 = command = "a"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = command = "a";-------
trigger2 = stateno = 600 ;jump_a
trigger2 = statetime >= 6

;---------------------------------------------------------------------------
;Jump_A Forward (Kneedrop)
[State -1]
type = ChangeState
value = 660
triggerall = Vel X != 0
trigger1 = command = "a"
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Jump_B
[State -1]
type = ChangeState
value = 630
trigger1 = command = "b"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = command = "b";-------
trigger2 = stateno = 600 ;jump_a
trigger2 = movecontact = 1

;---------------------------------------------------------------------------
;Jump_B Moving
[State -1]
type = ChangeState
value = 650
trigger1 = command = "c"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = command = "b";-------
trigger2 = stateno = 600 ;jump_a
trigger2 = movecontact = 1
                    
